@@ -164,6 +164,8 @@ class WeightsLoaderHelper:
             logger.info(
                 "Some module weights could not be found in loaded weights file: {}".format(", ".join(missing_keys))
             )
+        if self.model._keys_to_ignore_on_load_unexpected:
+            unexpected_keys = [k for k in unexpected_keys if k not in self.model._keys_to_ignore_on_load_unexpected]
         if len(unexpected_keys) > 0:
             logger.info(
                 "Some weights of the state_dict could not be loaded into model: {}".format(", ".join(unexpected_keys))
@@ -303,6 +305,8 @@ class AdapterLoader(WeightsLoader):
             lambda x: "_adapters.{}.".format(adapter_name) in x
             or ".adapters.{}.".format(adapter_name) in x
             or ".prefix_tunings.{}.".format(adapter_name) in x
+            or ".prefix_gates.{}.".format(adapter_name) in x
+            or ".loras.{}.".format(adapter_name) in x
         )
 
     # This dict maps the original weight names to the currently used equivalents.
@@ -345,6 +349,8 @@ class AdapterLoader(WeightsLoader):
             lambda k: self._rename_legacy_weights(k)
             .replace("adapters.{}.".format(old_name), "adapters.{}.".format(new_name))
             .replace(".prefix_tunings.{}.".format(old_name), ".prefix_tunings.{}.".format(new_name))
+            .replace(".prefix_gates.{}.".format(old_name), ".prefix_gates.{}.".format(new_name))
+            .replace(".loras.{}.".format(old_name), ".loras.{}.".format(new_name))
         )
 
     def save(self, save_directory, name, meta_dict=None):
@@ -682,7 +688,10 @@ class PredictionHeadLoader(WeightsLoader):
             config = self.weights_helper.load_weights_config(save_directory)
             # make sure that the model class of the loaded head matches the current class
             if not self.convert_to_flex_head and self.model.__class__.__name__ != config["model_class"]:
-                error_msg = f"Model class '{config['model_class']}' of found prediction head does not match current model class."
+                error_msg = (
+                    f"Model class '{config['model_class']}' of found prediction head does not match current model"
+                    " class."
+                )
                 if self.error_on_missing:
                     raise ValueError(error_msg)
                 else:
@@ -703,7 +712,8 @@ class PredictionHeadLoader(WeightsLoader):
                         head_config = config["config"]
                     else:
                         raise ValueError(
-                            f"Cannot automatically convert prediction head of model class {config['model_class']} to flex head."
+                            f"Cannot automatically convert prediction head of model class {config['model_class']} to"
+                            " flex head."
                         )
                 # try to convert a static head to a flex head
                 elif self.convert_to_flex_head and config["model_class"] in STATIC_TO_FLEX_HEAD_MAP:
@@ -720,7 +730,8 @@ class PredictionHeadLoader(WeightsLoader):
                     )
                 else:
                     raise ValueError(
-                        f"Cannot automatically convert prediction head of model class {config['model_class']} to flex head."
+                        f"Cannot automatically convert prediction head of model class {config['model_class']} to flex"
+                        " head."
                     )
                 if head_name in self.model.heads:
                     logger.warning("Overwriting existing head '{}'".format(head_name))
